@@ -24,7 +24,7 @@ use strict;
 use warnings;
 
 use vars qw/$VERSION/;
-$VERSION = '0.49';
+$VERSION = '0.51';
 $VERSION = eval $VERSION;
 
 use Error qw(:try);
@@ -62,6 +62,10 @@ sub new {
     my %opts = @_;
 
     while (my ($k, $v) = each(%opts)) {
+        # in _rest we concatenate server with '/REST/1.0';
+        if ($k eq 'server') {
+            $v =~ s!/$!!;
+        }
         $self->$k($v);
     }
 
@@ -148,7 +152,32 @@ sub get_attachment_ids {
         RT::Client::REST::Exception->_rt_content_to_exception($c)->throw;
     }
 
-    return $k->{Attachments} =~ m/(\d+):/mg;
+    return $k->{Attachments} =~ m/^\s*(\d+):/mg;
+}
+
+sub get_attachments_metadata {
+    my $self = shift;
+
+    $self->_assert_even(@_);
+
+    my %opts = @_;
+
+    my $type = $self->_valid_type(delete($opts{type}) || 'ticket');
+    my $id = $self->_valid_numeric_object_id(delete($opts{id}));
+
+    my $form = form_parse(
+        $self->_submit("$type/$id/attachments/")->decoded_content
+    );
+    my ($c, $o, $k, $e) = @{$$form[0]};
+
+    if (!@$o && $c) {
+        RT::Client::REST::Exception->_rt_content_to_exception($c)->throw;
+    }
+    return map {
+      # Matches: '50008989: (Unnamed) (text/plain / 1.9k),'
+      my @c = $_ =~ m/^\s*(\d+):\s+(.+)\s+\(([^\s]+)\s+\/\s+([^\s]+)\)\s*,\s*$/;
+      { id => $c[0], Filename => $c[1] eq '(Unnamed)' ? undef : $c[1], Type => $c[2], Size => $c[3] };
+    } split(/\n/, $k->{Attachments});
 }
 
 sub get_attachment {
@@ -1007,8 +1036,8 @@ using C<show()> method:
     query => "Status = 'stalled'",
   );
   for my $id (@ids) {
-    my ($ticket) = $rt->show(type => 'ticket', ids => [$id]);
-    print "Subject: ", $t->{Subject}, "\n";
+    my ($ticket) = $rt->show(type => 'ticket', id => $id);
+    print "Subject: ", $ticket->{Subject}, "\n";
   }
 
 =item comment (ticket_id => $id, message => $message, %opts)
@@ -1033,6 +1062,18 @@ B<bcc>, and B<attachments> parameters (see C<comment> above).
 
 Get a list of numeric attachment IDs associated with ticket C<$id>.
 
+=item get_attachments_metadata (id => $id)
+
+Get a list of the metadata related to every attachment of the ticket <$id>
+Every member of the list is a hashref with the shape:
+
+  {
+    id       => $attachment_id,
+    Filename => $attachment_filename,
+    Type     => $attachment_type,
+    Size     => $attachment_size,
+  }
+
 =item get_attachment (parent_id => $parent_id, id => $id, undecoded => $bool)
 
 Returns reference to a hash with key-value pair describing attachment
@@ -1234,7 +1275,7 @@ RT server, which is either good or bad, depending how you look at it.
 
 =head1 VERSION
 
-This is version 0.49 of B<RT::Client::REST>.
+This is version 0.51 of B<RT::Client::REST>.
 
 =head1 AUTHORS
 
@@ -1242,6 +1283,7 @@ Original /usr/bin/rt was written by Abhijit Menon-Sen <ams@wiw.org>.  rt
 was later converted to this module by Dmitri Tikhonov <dtikhonov@yahoo.com>.
 In January of 2008, Damien "dams" Krotkine <dams@cpan.org> joined as the
 project's co-maintainer. JLMARTIN has become co-maintainer as of March 2010.
+SRVSH became a co-maintainer in November 2015.
 
 =head1 LICENSE
 
