@@ -463,7 +463,7 @@ sub from_form {
     # Now set attributes:
     while (my ($key, $value) = each(%$hash)) {
         # Handle custom fields, ideally /(?(1)})/ would be appened to RE
-	if( $key =~ m%^(?:cf|customfield)(?:-|\.{)([#\s\w_:()?/-]+)% ){
+	if( $key =~ m%^(?:cf|customfield)(?:-|\.\{)([#\s\w_:()?/-]+)% ){
 	    $key = $1;
 
             # XXX very sketchy. Will fail on long form data e.g; wiki CF
